==> three.quarks-0.12.4.tgz: package/src/behaviors/RotationOverLife.ts <==
import {Behavior} from './Behavior';
import {Particle, SpriteParticle} from '../Particle';
import {FunctionValueGenerator, ValueGenerator, ValueGeneratorFromJSON} from '../functions/ValueGenerator';
import {Quaternion} from 'three';
import {ConstantValue, IntervalValue} from '../functions';

export class RotationOverLife implements Behavior {
    type = 'RotationOverLife';
    private dynamic: boolean;

    constructor(public angularVelocity: ValueGenerator | FunctionValueGenerator) {
        this.dynamic = !(angularVelocity instanceof ConstantValue || angularVelocity instanceof IntervalValue);
    }

    initialize(particle: Particle): void {
        this.dynamic = !(
            this.angularVelocity instanceof ConstantValue || this.angularVelocity instanceof IntervalValue
        );
        if (!this.dynamic && typeof particle.rotation === 'number') {
            (particle as any).angularVelocity = (this.angularVelocity as ValueGenerator).genValue();
        }
    }

    update(particle: Particle, delta: number): void {
        if (!this.dynamic) {
            if (typeof particle.rotation === 'number') {
                (particle.rotation as number) += delta * ((particle as any).angularVelocity as number);
            }
        } else {
            if (typeof particle.rotation === 'number') {
                (particle.rotation as number) +=
                    delta * (this.angularVelocity as FunctionValueGenerator).genValue(particle.age / particle.life);
            }
        }
    }

    toJSON(): any {
        return {
            type: this.type,
            angularVelocity: this.angularVelocity.toJSON(),
        };
    }

    static fromJSON(json: any): Behavior {
        return new RotationOverLife(ValueGeneratorFromJSON(json.angularVelocity) as FunctionValueGenerator);
    }

    frameUpdate(delta: number): void {}

    clone(): Behavior {
        return new RotationOverLife(this.angularVelocity.clone());
    }
    reset(): void {}
}

==> three.quarks-0.13.0.tgz: package/src/behaviors/RotationOverLife.ts <==
import {Behavior} from './Behavior';
import {Particle, SpriteParticle} from '../Particle';
import {FunctionValueGenerator, ValueGenerator, ValueGeneratorFromJSON} from '../functions/ValueGenerator';
import {Quaternion} from 'three';
import {ConstantValue, IntervalValue} from '../functions';

/**
 * Apply rotation to particles over their life.
 */
export class RotationOverLife implements Behavior {
    type = 'RotationOverLife';

    constructor(public angularVelocity: ValueGenerator | FunctionValueGenerator) {}

    initialize(particle: Particle): void {
        if (typeof particle.rotation === 'number') {
            (this.angularVelocity as ValueGenerator).startGen(particle.memory);
        }
    }

    update(particle: Particle, delta: number): void {
        if (typeof particle.rotation === 'number') {
            (particle.rotation as number) +=
                delta *
                (this.angularVelocity as FunctionValueGenerator).genValue(
                    particle.memory,
                    particle.age / particle.life
                );
        }
    }

    toJSON(): any {
        return {
            type: this.type,
            angularVelocity: this.angularVelocity.toJSON(),
        };
    }

    static fromJSON(json: any): Behavior {
        return new RotationOverLife(ValueGeneratorFromJSON(json.angularVelocity) as FunctionValueGenerator);
    }

    frameUpdate(delta: number): void {}

    clone(): Behavior {
        return new RotationOverLife(this.angularVelocity.clone());
    }
    reset(): void {}
}
